aboutsummaryrefslogtreecommitdiffhomepage
path: root/tools
diff options
context:
space:
mode:
authorGravatar Stanley Cheung <stanleycheung@google.com>2016-02-23 22:39:25 -0800
committerGravatar Stanley Cheung <stanleycheung@google.com>2016-02-23 22:39:25 -0800
commitbf74d69ed601796fca2d6e737519cc1c2de7c60c (patch)
treed93f9c8f7faf8167f0db13a0d3358276ceded8bd /tools
parent5adb71fb9add555ac161ebf745e5ac104fe3f847 (diff)
fix php artifact name and update config.m4 template
Diffstat (limited to 'tools')
-rw-r--r--tools/run_tests/artifact_targets.py10
-rw-r--r--tools/run_tests/package_targets.py2
2 files changed, 6 insertions, 6 deletions
diff --git a/tools/run_tests/package_targets.py b/tools/run_tests/package_targets.py
index 8aee1f86de..87bc4865ce 100644
--- a/tools/run_tests/package_targets.py
+++ b/tools/run_tests/package_targets.py
@@ -140,7 +140,7 @@ class PythonPackage:
class PHPPackage:
- """Builds PHP PECL package and collects precompiled package"""
+ """Copy PHP PECL package artifact"""
def __init__(self):
self.name = 'php_package'
diff --git a/tools/run_tests/artifact_targets.py b/tools/run_tests/artifact_targets.py
index 15a1e2a681..803d3d106b 100644
--- a/tools/run_tests/artifact_targets.py
+++ b/tools/run_tests/artifact_targets.py
@@ -241,11 +241,11 @@ class NodeExtArtifact:
['tools/run_tests/build_artifact_node.sh',
self.gyp_arch])
-class PHPExtArtifact:
- """Builds PHP native extension"""
+class PHPArtifact:
+ """Builds PHP PECL package"""
def __init__(self, platform, arch):
- self.name = 'php_ext_{0}_{1}'.format(platform, arch)
+ self.name = 'php_pecl_package_{0}_{1}'.format(platform, arch)
self.platform = platform
self.arch = arch
self.labels = ['artifact', 'php', platform, arch]
@@ -317,5 +317,5 @@ def targets():
RubyArtifact('linux', 'x86'),
RubyArtifact('linux', 'x64'),
RubyArtifact('macos', 'x64'),
- PHPExtArtifact('linux', 'x64'),
- PHPExtArtifact('macos', 'x64')])
+ PHPArtifact('linux', 'x64'),
+ PHPArtifact('macos', 'x64')])